==> kmud-0.5.tar.gz: kmud-0.5/kmud/kmudplugin.cpp <==
/***************************************************************************
                          kmudplugin.cpp
                      -------------------
    description          : Base class for all plugins
    begin                : Mon May 15 2000
    copyright            : (C) 2000 by Stephan Uhlmann
    email                : suhlmann@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "kmudplugin.h"
#include <qpopupmenu.h>

KmudPlugin::KmudPlugin()
{
	name="";
	version="";
	description="";
	author="";
	email="";
	homepage="";
	copyright="";

	configurable=false;
}

KmudPlugin::~KmudPlugin()
{
}


void KmudPlugin::init(KmudAPI* pkmud)
{
	kmudapi=pkmud;
}

QString KmudPlugin::getName()
{
	return name;
}

QString KmudPlugin::getVersion()
{
	return version;
}

QString KmudPlugin::getDescription()
{
	return description;
}


QString KmudPlugin::getAuthor()
{
	return author;
}

QString KmudPlugin::getEmail()
{
	return email;
}

QString KmudPlugin::getHomepage()
{
	return homepage;
}

QString KmudPlugin::getCopyright()
{
	return copyright;
}

bool KmudPlugin::isConfigurable()
{
	return configurable;
}

QString KmudPlugin::processInput(QString s)
{
	return s;
}

QString KmudPlugin::processRawOutput(QString s)
{
	return s;
}

QString KmudPlugin::processParsedOutput(QString s)
{
	return s;
}

void KmudPlugin::callConfigDialog()
{
}

==> kmud-1.0.tar.gz: kmud-1.0/kmud/kmudplugin.cpp <==
/***************************************************************************
                          kmudplugin.cpp
                      -------------------
    description          : Base class for all plugins
    begin                : Mon May 15 2000
    copyright            : (C) 2000 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "kmudplugin.h"
#include <qpopupmenu.h>

KmudPlugin::KmudPlugin()
{
	name="";
	version="";
	description="";
	author="";
	email="";
	homepage="";
	copyright="";

	configurable=false;
}

KmudPlugin::~KmudPlugin()
{
}


void KmudPlugin::init(KmudAPI* pkmud)
{
	kmudapi=pkmud;
}

QString KmudPlugin::getName()
{
	return name;
}

QString KmudPlugin::getVersion()
{
	return version;
}

QString KmudPlugin::getDescription()
{
	return description;
}


QString KmudPlugin::getAuthor()
{
	return author;
}

QString KmudPlugin::getEmail()
{
	return email;
}

QString KmudPlugin::getHomepage()
{
	return homepage;
}

QString KmudPlugin::getCopyright()
{
	return copyright;
}

bool KmudPlugin::isConfigurable()
{
	return configurable;
}

QString KmudPlugin::processInput(QString s)
{
	return s;
}

QString KmudPlugin::processRawOutput(QString s)
{
	return s;
}

QString KmudPlugin::processParsedOutput(QString s)
{
	return s;
}

void KmudPlugin::callConfigDialog()
{
}
